# bilibili 封面图查看

nonebot-plugin-bilibilicover

## 功能

通过发送视频 AV 或 BV 号来获取视频封面图

## 安装

### 1.从 github 仓库下载

```url
url:https://github.com/kamuxiy/nonebot-plugin-bilibilicover
```

### 2.通过 pip

```shell script
python install nonebot-plugin-bilibilicover
```

## 开始使用

示例命令：

```
/封面图 av545905283
/封面图 BV1eq4y1j7BQ
```

## 特别感谢

- Mrs4s / go-cqhttp
- nonebot / nonebot2

## 提供建议

[issues](https://github.com/kamuxiy/nonebot-plugin-bilibilicover/issues)
